.. _api:

API Reference
=============
|

The StreamSets SDK for Python is broadly divided into abstractions for interacting with StreamSets Data Collector,
StreamSets Control Hub, and StreamSets Transformer.

.. toctree::
   :maxdepth: 2

   api/sch_api
   api/sdc_api
   api/st_api


